@@ -1,3 +1,4 @@
+import re
 import copy
 import xml.etree.ElementTree as etree
 
@@ -80,5 +81,6 @@ class BackslashPostProcessor(Postprocessor):
 
 	def run(self, text):
 		text = text.replace('<br />\n', '</li>\n<li>')
+		text = re.sub(r'<a href="(.*)"><img', r'<a href="\1" class="none"><img', text)
 		return text
 
